From 7294c912c79397ff345dd0da0d4a545ad9d0ab7a Mon Sep 17 00:00:00 2001
From: Peter Eisentraut <peter@eisentraut.org>
Date: Wed, 1 Nov 2023 05:48:24 -0400
Subject: [PATCH v3 2/4] Enable abidw option on Cirrus CI

---
 .cirrus.tasks.yml | 18 ++++++++++++++++--
 1 file changed, 16 insertions(+), 2 deletions(-)

diff --git a/.cirrus.tasks.yml b/.cirrus.tasks.yml
index e137769850d..f13a0eeeb7b 100644
--- a/.cirrus.tasks.yml
+++ b/.cirrus.tasks.yml
@@ -164,6 +164,7 @@ task:
     sysctl kern.corefile='/tmp/cores/%N.%P.core'
   setup_additional_packages_script: |
     #pkg install -y ...
+    pkg install -y libabigail
 
   # NB: Intentionally build without -Dllvm. The freebsd image size is already
   # large enough to make VM startup slow, and even without llvm freebsd
@@ -172,6 +173,7 @@ task:
     su postgres <<-EOF
       meson setup \
         --buildtype=debug \
+        -Dabidw=enabled \
         -Dcassert=true -Duuid=bsd -Dtcl_version=tcl86 -Ddtrace=auto \
         -DPG_TEST_EXTRA="$PG_TEST_EXTRA" \
         -Dextra_lib_dirs=/usr/local/lib -Dextra_include_dirs=/usr/local/include/ \
@@ -201,6 +203,11 @@ task:
       build/tmp_install/usr/local/pgsql/bin/pg_ctl -D build/runningcheck stop
     EOF
 
+  always:
+    abidw_artifacts:
+      path: "build/**/*.abi.xml"
+      type: application/xml
+
   on_failure:
     # if the server continues running, it often causes cirrus-ci to fail
     # during upload, as it doesn't expect artifacts to change size
@@ -309,8 +316,8 @@ task:
     EOF
 
   setup_additional_packages_script: |
-    #apt-get update
-    #DEBIAN_FRONTEND=noninteractive apt-get -y install ...
+    apt-get update
+    DEBIAN_FRONTEND=noninteractive apt-get -y install abigail-tools
 
   matrix:
     - name: Linux - Debian Bullseye - Autoconf
@@ -357,6 +364,7 @@ task:
         su postgres <<-EOF
           meson setup \
             --buildtype=debug \
+            -Dabidw=enabled \
             -Dcassert=true \
             ${LINUX_MESON_FEATURES} \
             -DPG_TEST_EXTRA="$PG_TEST_EXTRA" \
@@ -370,6 +378,7 @@ task:
           export CC='ccache gcc -m32'
           meson setup \
             --buildtype=debug \
+            -Dabidw=enabled \
             -Dcassert=true \
             ${LINUX_MESON_FEATURES} \
             -Dllvm=disabled \
@@ -402,6 +411,11 @@ task:
           PYTHONCOERCECLOCALE=0 LANG=C meson test $MTEST_ARGS -C build-32 --num-processes ${TEST_JOBS}
         EOF
 
+      always:
+        abidw_artifacts:
+          path: "build/**/*.abi.xml"
+          type: application/xml
+
       on_failure:
         <<: *on_failure_meson
 
-- 
2.42.0

